# 
## 该文档描述了python 探针版本迭代以及相关功能的变化
## 更多帮助和支持请访问www.tingyun.com 或者直接联系我们的技术支持
#

2016-08-01  Version：1.0.6
--  增加： 模块piston框架的支持
--  增加： 开启tornado4支持，并支持wsgi模式
--  修复： flask框架，因错误参数，导致注册错误处理器失败的问题。


2016-06-24  Version：1.0.6
--  增加：增加外部追踪错误的采集，支持requests、urllib3、urllib2、urllib、httplib2、thrift
--  增加：自定义web应用过程命名
--  增加：外部请求错误追踪功能
--  修复：应用容器父进程中，调用应用导致探针不能捕获性能数据的问题


2016-06-16  Version：1.0.1
--  增加：支持代理功能上报数据.
--  增加：支持bottle框架，支持范围0.10.x-0.12.x

2016-1-28  Version：0.9.1
--  修复：urllib3不能采集get参数的问题
--  修复：修复错误的urllib3导致参数解析错误的问题

2016-1-28  Version：0.9.0
--  增加：对以下插件的对外调用，支持听云探针之间的跨应用追踪
        -- requests
        -- httplib2
        -- urllib3

2015-12-30  Version：0.8.0
--  增加：框架tornado的支持,支持范围v3.x.x-v4.x.x（该框架不支持browser探针自动嵌码）
--  增加：增加verify_certification配置项，用于解决ssl传输数据时校验服务器证书认证失败的问题。
--  增加：增加对flask框架的蓝图组件的性能追踪。

2015-12-02  Version：0.7.7
--  增加：支持browser探针自动嵌码
--  增加：对browser探针增加配置项

2015-11-20  Version：0.7.5
--  增加：增加gevent部署方式的入口检测，支持范围0.13.0-1.0.2 release
--  增加：增加应用阻塞时间采集
--  增加：增加多个appName的支持
--  增加：在文档中增加对部署探针常见问题的汇总
--  修复：修复错误配置项导致探针无法启动的问题

2015-10-28  Version：0.7.0
--  增加：web2py框架的支持，支持范围2.8.1-2.12.x
--  增加：开放探针部分API
--  增加：增加各个框架版本信息的上报
--  修复：修复flask框架下模板检测的错误

2015-10-27  Version：0.6.7
--  修复：修复了用户在开启追踪应用阻塞时间时，数据计算错误的问题
--  修复：修复了配置文件因使用中文应用名称导致数据上报失败的问题

2015-10-26  Version：0.6.6
--  增加：webpy框架的支持，支持范围0.3.x
--  增加：模板mako支持，支持范围v0.7.x-v1.0.x
--  增加：一键嵌入探针时若无法找到配置文件，提示未生效该次操作

2015-09-25  Version：0.6.3
--  增加：框架flask的支持, 支持范围0.6-0.10
--  增加：jinja2模板性能检测的支持, 支持范围2.3以上版本
--  修复：默认statuscode造成的服务端数据入库问题
--  增加：支持用户私有化探针

2015-08-28  Version：0.5.4
--  增加：数据库追踪类型
--  增加：cpu、内存的实时采样
--  增加：服务器端配置（参数命名应用过程，暂支持url参数）
--  增加：外部调用redis、requests、httplib2的支持
--  增加：对django框架内部异常采集。

2015-08-06  Version：0.4.3
--  修复：修复在线安装默认配置文件丢失问题
--  修复：线程剖析潜在可能崩溃的bug

2015-08-06  Version：0.4.2
--  增加：性能剖析功能
--  增加：generate-config命令
--  增加：源码安装支持跨目录安装
--  增加：支持pip、easy_install方式安装
--  修复：更详细的python环境信息
--  修复：探针内核修复，增加稳定性
--  修复：其他小细节以及bug

2015-06-29  Version：0.3.0
--  增加：redis的性能数据监测
--  增加：mongodb的性能数据监测
--  增加：增加check-config命令，用于对配置文件进行校验。
